/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2008. All Rights Reserved.
 *  
 * U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 ******************************************************************************/
package com.ibm.rational.test.lm.spi.driver.test;

import java.net.URI;
import java.util.HashMap;

import com.ibm.ccl.soa.deploy.core.Topology;
import com.ibm.ccl.soa.deploy.operation.OperationUnit;
import com.ibm.rational.test.lm.spi.IAutomationSPI;
import com.ibm.rational.test.lm.spi.common.IRestAPIResponseCodes;
import com.ibm.rational.test.lm.spi.common.IRestResponse;
import com.ibm.rational.test.lm.spi.driver.test.util.ProviderXml;
import com.ibm.rational.test.lm.spi.driver.test.util.Registry;
import com.ibm.rational.test.lm.spi.driver.test.util.TestTracer;
import com.ibm.rational.test.lm.spi.driver.test.util.TopologyUtils;
import junit.framework.TestCase;

public class Automation extends TestCase 
{
	
    private static HashMap<String, String> providerToConfig = new HashMap<String, String>();    
    private static boolean isInited = false;
    private static boolean isProviderChecked = false;
               
    private IAutomationSPI suite_automationProvider = null;
    private String suite_automationProviderPluginId = null;
    private String suite_baseJobDefinitionUrls = null;

    
    public Automation(String strTestCase, IAutomationSPI asuite_automationProvider, 
    		String asuite_automationProviderPluginId, String asuite_baseJobDefinitionUrls) {
        super(strTestCase);
    	this.suite_automationProvider = asuite_automationProvider;
        this.suite_automationProviderPluginId = asuite_automationProviderPluginId;
        this.suite_baseJobDefinitionUrls = asuite_baseJobDefinitionUrls;
    }
 
    
    public Automation() {
        super();
    }
    
    
    protected void setUp() throws Exception
    {
        //if provider is null, out.println the error message..
    	if ((!isProviderChecked)&&(suite_automationProvider == null)){
    		System.out.println("Providers not assigned!" +
    				"\nTestCase setUp() failure!" +	
    				"\nThis testCase can not run seperately!");
    		    		
    		isProviderChecked = true;
    	}
    	assertNotNull(suite_automationProvider);

    	
        assertNotNull(Registry.getRegistry().getAutomationProviders());
        if (!isInited)
        {
            assertTrue(initSPIData());
            isInited = true;
        }       
    }
    

    private boolean initSPIData()
    {
        boolean success = false;

        providerToConfig = ProviderXml.getAutomationProviderDocs();
        success = providerToConfig.size() > 0;
                
        return success;
    }
    
    
    
    /**
     * test call of init() for automation provider
     */
    public void testInit()
    {
        
        try
        {
        	suite_automationProvider.init(
                    providerToConfig.get(suite_automationProviderPluginId),
                    new TestTracer());           	
        }
        catch (Exception e)
        {
        	//	        System.out.println("\tException in: " + suite_automationProviderPluginId);
            fail("Exception in Init(): " + e.toString());
        }
                
    }
    
    
    /**
     * test get() of /jobDefinition/ to retrieve ids of all jobs the provider knows about, in TDM Operational Model.
     */
    public void testGetJobDefinitionIds()
    {
    	
    	try
        {
          
	            IRestResponse restResponse = 
	            	suite_automationProvider.get(new URI(suite_baseJobDefinitionUrls));
	            
	            assertTrue(restResponse.getResponseCode() == IRestAPIResponseCodes.SC_OK);
	            String response = restResponse.getXMLResponse();
	            assertNotNull(response);
	            Topology jobDefs = TopologyUtils.parseTopologyFromXml(response);
	            assertNotNull(jobDefs);
	            assertTrue(jobDefs.getUnits().get(0) instanceof OperationUnit);
	            
        }        
        catch (Exception e)
        {
            fail(e.toString());
        }   
        
        
        
    }
    
    
    /**
     * test get() of /jobDefinition/ to retrieve a TDM Model describing all known jobs.
     */
    public void testGetAllJobDefinitions()
    {
        
        try
        {
	            IRestResponse restResponse =
	            	suite_automationProvider.get(new URI(suite_baseJobDefinitionUrls));	                       
	            
	            assertTrue(restResponse.getResponseCode() == IRestAPIResponseCodes.SC_OK);
	            String response = restResponse.getXMLResponse();
	            assertNotNull(response);
	            Topology jobDefs = TopologyUtils.parseTopologyFromXml(response);
	            assertNotNull(jobDefs);
	            assertTrue(jobDefs.getUnits().get(0) instanceof OperationUnit);
	            
        }        
        catch (Exception e)
        {
            fail(e.toString());
        }
        
    }
        
}
