/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2008, 2009. All Rights Reserved.
 *  
 * U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 ******************************************************************************/
package com.ibm.rational.test.lm.spi.driver.test;

import java.net.URI;
import java.util.HashMap;

import junit.framework.TestCase;

import com.ibm.ccl.soa.deploy.core.Topology;
import com.ibm.ccl.soa.deploy.server.ServerUnit;
import com.ibm.rational.test.lm.spi.IInventorySPI;
import com.ibm.rational.test.lm.spi.common.IRestAPIResponseCodes;
import com.ibm.rational.test.lm.spi.common.IRestResponse;
import com.ibm.rational.test.lm.spi.driver.test.util.ProviderXml;
import com.ibm.rational.test.lm.spi.driver.test.util.Registry;
import com.ibm.rational.test.lm.spi.driver.test.util.TestTracer;
import com.ibm.rational.test.lm.spi.driver.test.util.TopologyUtils;

public class Inventory extends TestCase 
{

    private static HashMap<String, String> providerToConfig = new HashMap<String, String>();    
    private static boolean isInited = false;
    private static boolean isProviderChecked = false;
     
    private String suite_baseAssetUrl = null;
    private IInventorySPI suite_inventoryProvider = null;
    private String suite_inventoryProviderPluginId = null;

    
    public Inventory(String strTestCase, IInventorySPI asuite_inventoryProvider, 
    		String asuite_inventoryProviderPluginId, String asuite_baseAssetUrl) {
        super(strTestCase);
    	this.suite_inventoryProvider = asuite_inventoryProvider;
        this.suite_inventoryProviderPluginId = asuite_inventoryProviderPluginId;
        this.suite_baseAssetUrl = asuite_baseAssetUrl;
    }
    
    
    public Inventory() {
        super();
    }

   
    
    protected void setUp() throws Exception
    {
        //if provider is null, out.println the error message..
    	if ((!isProviderChecked)&&(suite_inventoryProvider == null)){
    		System.out.println("Providers not assigned!" +
    				"\nTestCase setUp() failure!" +	
    				"\nThis testCase can not run seperately!");
    		
    		isProviderChecked = true;
    	}
    	assertNotNull(suite_inventoryProvider);
    	
    	
        assertNotNull(Registry.getRegistry().getInventoryProviders());
        if (!isInited)
        {
            assertTrue(initSPIData());
            isInited = true;
        }      
    }
    
    
    private boolean initSPIData()
    {
        boolean success = false;

        providerToConfig = ProviderXml.getInventoryProviderDocs();
        
        success = providerToConfig.size() > 0;
              
        return success;
    }
    
    
    /**
     * test call of init() for inventory provider
     */
    public void testInit()
    {

    	try
        {
        	suite_inventoryProvider.init(
                    providerToConfig.get(suite_inventoryProviderPluginId),
                    new TestTracer());           	
        }
        catch (Exception e)
        {
        	//System.out.println("\tException in: " + suite_inventoryProviderPluginId);
            fail("Exception in Init(): " + e.toString());
        }
        
        
    }
    
    /**
     * test get() of /asset/ to retrieve ids of all assets the provider knows about, in TDM Operational Model.
     */
    public void testGetAssetIds()
    {   
    	
    	try
        {           	
	            IRestResponse restResponse = suite_inventoryProvider.get(new URI(suite_baseAssetUrl));
	            assertTrue(restResponse.getResponseCode() == IRestAPIResponseCodes.SC_OK);
	            String response = restResponse.getXMLResponse();
	            assertNotNull(response);
	            Topology assets = TopologyUtils.parseTopologyFromXml(response);
	            assertNotNull(assets);
	            assertTrue(assets.getUnits().get(0) instanceof ServerUnit);
        }        
        catch (Exception e)
        {
            fail(e.toString());
        }
   	    	
    }
    
    /**
     * test get() of /asset/* to retrieve a TDM model of all the assets the provider knows about. 
     */
    public void testGetAllAssets()
    {

    	try
        {
	            IRestResponse restResponse = suite_inventoryProvider.get(new URI(suite_baseAssetUrl + "*"));
	            assertTrue(restResponse.getResponseCode() == IRestAPIResponseCodes.SC_OK);
	            String response = restResponse.getXMLResponse();
	            assertNotNull(response);
	            Topology assets = TopologyUtils.parseTopologyFromXml(response);
	            assertNotNull(assets);
	            assertTrue(assets.getUnits().get(0) instanceof ServerUnit);
        }        
        catch (Exception e)
        {
            fail(e.toString());
        }  
                   	
    }
    
}
