/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2008. All Rights Reserved.
 *  
 * U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 ******************************************************************************/
package com.ibm.rational.test.lm.spi.driver.test.util;

import org.eclipse.core.runtime.IConfigurationElement;
import org.eclipse.core.runtime.IExtensionRegistry;
import org.eclipse.core.runtime.Platform;

import com.ibm.rational.test.lm.spi.IAutomationSPI;
import com.ibm.rational.test.lm.spi.IInventorySPI;
import com.ibm.rational.test.lm.spi.IVirtualizationSPI;

public class Registry 
{
    private static final String automationExtensionPoint = "com.ibm.rational.test.lm.spi.automation";
    private static final String inventoryExtensionPoint = "com.ibm.rational.test.lm.spi.inventory";
    private static final String virtualizationExtensionPoint = "com.ibm.rational.test.lm.spi.virtualization";
    private static final String clzz = "class";
    
    private static Registry registryInstance = new Registry();

    private IInventorySPI[] inventoryProviders = null;       
    private String[] inventoryProviderPluginIds = null;
    private IAutomationSPI[] automationProviders = null;
    private String[] automationProviderPluginIds = null;    
    private IVirtualizationSPI[] virtualizationProviders = null;
    private String[] virtualizationProviderPluginIds = null;
   
    
    private Registry()
    {
        get_Automation_Plugins();
        get_Inventory_Plugins();
        get_Virtualization_Plugins();
    }
    
    
    private void get_Automation_Plugins()
    {
        IExtensionRegistry registry = Platform.getExtensionRegistry();
        IConfigurationElement[] elements = null;
        int iElements_Num = 0;
    	
        
        elements = registry.getConfigurationElementsFor(automationExtensionPoint);

        iElements_Num = elements.length;
        automationProviders = new IAutomationSPI[iElements_Num];
        automationProviderPluginIds = new String[iElements_Num];

        
        int i = 0;
        System.out.println("Registering Automation Extension: ");
        for (IConfigurationElement element : elements)
        {
       	
            try
            {
            	automationProviders[i] = (IAutomationSPI)element.createExecutableExtension(clzz);
            	automationProviderPluginIds[i] = element.getAttribute("id");
                System.out.println("\t" + automationProviderPluginIds[i]);
 
                i++;
            }
            catch (Exception e)
            {
                System.out.println("Error Registering Automation Extension " + element.getAttribute("id") + ": " + e.toString());
            }
       	            
        }
        System.out.println();
    }
 
    private void get_Inventory_Plugins()
    {
    	
        IExtensionRegistry registry = Platform.getExtensionRegistry();
        IConfigurationElement[] elements = null;
        int iElements_Num = 0;
    	
        
        elements = registry.getConfigurationElementsFor(inventoryExtensionPoint);

        iElements_Num = elements.length;
        inventoryProviders = new IInventorySPI[iElements_Num];
        inventoryProviderPluginIds = new String[iElements_Num];
        
        int i = 0;
        System.out.println("Registering Inventory Extension: ");
        for (IConfigurationElement element : elements)
        {
       	
            try
            {
            	inventoryProviders[i] = (IInventorySPI)element.createExecutableExtension(clzz);
            	inventoryProviderPluginIds[i] = element.getAttribute("id");
                System.out.println("\t" + inventoryProviderPluginIds[i]);
 
                i++;
            }
            catch (Exception e)
            {
                System.out.println("Error Registering Inventory Extension " + element.getAttribute("id") + ": " + e.toString());
            }
       	            
        }
        System.out.println();
        
    }
  
    private void get_Virtualization_Plugins()
    {
        IExtensionRegistry registry = Platform.getExtensionRegistry();
        IConfigurationElement[] elements = null;
        int iElements_Num = 0;
     	
        
        elements = registry.getConfigurationElementsFor(virtualizationExtensionPoint);

        iElements_Num = elements.length;
        virtualizationProviders = new IVirtualizationSPI[iElements_Num];
        virtualizationProviderPluginIds = new String[iElements_Num];
        
        int i = 0;
        System.out.println("Registering Virtualization Extension: ");
        for (IConfigurationElement element : elements)
        {
       	
            try
            {
            	virtualizationProviders[i] = (IVirtualizationSPI)element.createExecutableExtension(clzz);
            	virtualizationProviderPluginIds[i] = element.getAttribute("id");
                System.out.println("\t" + virtualizationProviderPluginIds[i]);
 
                i++;
            }
            catch (Exception e)
            {
                System.out.println("Error Registering Virtualization Extension " + element.getAttribute("id") + ": " + e.toString());
            }
       	            
        }
        System.out.println();
   	
    }
 
    
    public static Registry getRegistry()
    {
        return registryInstance;
    }
    
    
    public IInventorySPI[] getInventoryProviders()
    {
        return inventoryProviders;
    }
    
    
    public String[] getInventoryProviderPluginIds()
    {
        return inventoryProviderPluginIds;
    }

    
    public IAutomationSPI[] getAutomationProviders()
    {
        return automationProviders;
    }
    
    public String[] getAutomationProviderPluginIds()
    {
        return automationProviderPluginIds;
    }
       
    public IVirtualizationSPI[] getVirtualizationProviders()
    {
        return virtualizationProviders;
    }
    
    public String[] getVirtualizationProviderPluginIds()
    {
        return virtualizationProviderPluginIds;
    }
    
    
}
