/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2008. All Rights Reserved.
 *  
 * U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 ******************************************************************************/
package com.ibm.rational.test.lm.spi.driver.test.util;

import java.io.IOException;
import java.util.HashMap;

import org.eclipse.emf.common.util.URI;
import org.eclipse.emf.ecore.resource.Resource;
import org.eclipse.emf.ecore.resource.ResourceSet;
import org.eclipse.emf.ecore.resource.URIConverter;
import org.eclipse.emf.ecore.resource.impl.ResourceSetImpl;
import org.eclipse.emf.ecore.xmi.XMLResource;

import com.ibm.ccl.soa.deploy.core.DeployCoreRoot;
import com.ibm.ccl.soa.deploy.core.Topology;
import com.ibm.ccl.soa.deploy.server.Server;
import com.ibm.ccl.soa.deploy.virtualization.VirtualImage;

public class TopologyUtils 
{
	
	private static final String VirtualImageIdAttribute = "ImageId"; //$NON-NLS-N$
	
    public static Topology parseTopologyFromXml(String xmlContent) 
    {
        Topology topology = null;
        try 
        {
            ResourceSet resourceSet = new ResourceSetImpl();
            Resource resource = resourceSet.createResource(URI.createURI("resource.extension"));
            HashMap<String, Boolean> options = new HashMap<String, Boolean>();

            options.put(XMLResource.OPTION_EXTENDED_META_DATA, Boolean.TRUE);
            resource.load(new URIConverter.ReadableInputStream(xmlContent), options);

            DeployCoreRoot root = (DeployCoreRoot) resource.getContents().get(0);
            topology = root.getTopology();
        } 
        catch (IOException e) 
        {
            e.printStackTrace();
        }
        return topology;
    }
    
    public static String parseVirtualImageId(VirtualImage virtualImage) {
    	String virtualImageId = null;
		if (virtualImage.getExtendedAttribute(VirtualImageIdAttribute) != null) {
			virtualImageId = (String) virtualImage.getExtendedAttribute(
					VirtualImageIdAttribute).getValue();
		}
		return virtualImageId;
    }
    
    public static String parseVirtualMachineId(Server virtualMachine) {
    	return virtualMachine.getSystemId();
    }
}
